@@ -967,6 +967,7 @@ class dataline(object):
         
         self.logger.info('Degridding run %s',self.id)
         
+        # degrid
         self.line_frame.grid_forget()
         self.line_frame.update_idletasks()
         
@@ -974,6 +975,10 @@ class dataline(object):
         del self.lines_list[self.id]
         del self.bfit.data[self.id]
         
+        # uncheck the fit
+        self.check_fit.set(False)
+        self.draw_fit_checkbox.config(state='disabled')
+        
         # repopulate fit files tab
         self.bfit.fit_files.populate()
         
